@@ -1,3 +1,27 @@
+'''
+MIT License
+
+Copyright (c) 2022 LearningToPi
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+
+'''
 import logging
 import logging.handlers
 from glob import glob
@@ -41,7 +65,7 @@ def create_logger(console_level='WARNING', log_file='', file_level='WARNING', na
     # Console
     if console:
         console_handler = logging.StreamHandler()
-        console_handler.setLevel(_log_level_name.get(console_level.upper() if not isinstance(console_level, int) else console_level, logging.INFO))
+        console_handler.setLevel(_log_level_name.get(console_level.upper(), logging.INFO) if not isinstance(console_level, int) else console_level)
         console_handler.setFormatter(formatter)
         logger.addHandler(console_handler)
 
@@ -49,7 +73,7 @@ def create_logger(console_level='WARNING', log_file='', file_level='WARNING', na
     if syslog:
         syslog_formatter = logging.Formatter(syslog_script_name + '[%(process)d]: %(levelname)s: %(message)s')
         syslog_handler = logging.handlers.SysLogHandler(address='/dev/log')
-        syslog_handler.setLevel(_log_level_name.get(file_level.upper() if not isinstance(file_level, int) else file_level, logging.WARNING))
+        syslog_handler.setLevel(_log_level_name.get(file_level.upper(), logging.WARNING) if not isinstance(file_level, int) else file_level)
         syslog_handler.setFormatter(syslog_formatter)
         logger.addHandler(syslog_handler)
 
@@ -60,7 +84,7 @@ def create_logger(console_level='WARNING', log_file='', file_level='WARNING', na
             if type(var) == dict and 'var' in var and 'set' in var and var['var'] == "{date}":
                 log_file = log_file.replace(var['var'], datetime.now().strftime(var['set']))
         file_handler = logging.FileHandler(log_file, mode=file_mode, encoding='utf-8', delay=False)
-        file_handler.setLevel(_log_level_name.get(file_level.upper() if not isinstance(file_level, int) else file_level, logging.WARNING))
+        file_handler.setLevel(_log_level_name.get(file_level.upper(), logging.WARNING) if not isinstance(file_level, int) else file_level)
         file_handler.setFormatter(formatter)
         logger.addHandler(file_handler)
 
